@@ -46,6 +46,7 @@
 #include <QStringList>
 #include <QMessageBox>
 #include <QUrl>
+#include <QDebug>
 
 #include "BookManipulation/FolderKeeper.h"
 #include "BookManipulation/CleanSource.h"
@@ -128,8 +129,17 @@ QSharedPointer<Book> ImportEPUB::GetBook(bool extract_metadata)
     AddObfuscatedButUndeclaredFonts(encrypted_files);
     AddNonStandardAppleXML();
     LoadInfrastructureFiles();
+    qDebug() << "m_ExtractedFolderPath: " << m_ExtractedFolderPath;
     // Check for files missing in the Manifest and create warning
     QStringList notInManifest;
+    qDebug() << "Zip File Paths: ";
+    foreach(QString fp, m_ZipFilePaths) {
+        qDebug() << "    " <<  fp;
+    }
+    qDebug() << "Manifest File Paths: ";
+    foreach(QString fp, m_ManifestFilePaths) {
+        qDebug() << "    " << fp;
+    }
     foreach(QString file_path, m_ZipFilePaths) {
         // skip mimetype and anything in META-INF and the opf itself
         if (file_path == "mimetype") continue;
@@ -139,6 +149,8 @@ QSharedPointer<Book> ImportEPUB::GetBook(bool extract_metadata)
 	    notInManifest << file_path;
 	}
     }
+    qDebug() << "missing file paths: " << notInManifest;
+    
     if (!notInManifest.isEmpty()) {
         Utility::DisplayStdWarningDialog(tr("Files exist in epub that are not listed in the manifest, they will be ignored"), notInManifest.join("\n"));
     }
@@ -153,7 +165,7 @@ QSharedPointer<Book> ImportEPUB::GetBook(bool extract_metadata)
     // let it modify the file.
     for (int i=0; i<resources.count(); ++i) {
         if (resources.at(i)->Type() == Resource::HTMLResourceType) {
-            HTMLResource *hresource = dynamic_cast<HTMLResource *>(resources.at(i));
+            HTMLResource *hresource = qobject_cast<HTMLResource *>(resources.at(i));
             if (!hresource) {
                 continue;
             }
@@ -200,29 +212,34 @@ QSharedPointer<Book> ImportEPUB::GetBook(bool extract_metadata)
         HTMLResource * nav_resource = NULL;
         if (m_NavResource) {
             if (m_NavResource->Type() == Resource::HTMLResourceType) {
-                nav_resource = dynamic_cast<HTMLResource*>(m_NavResource);
+                nav_resource = qobject_cast<HTMLResource*>(m_NavResource);
             }
         }
         if (!nav_resource) { 
             // we need to create a nav file here because one was not found
             // it will automatically be added to the content.opf
             nav_resource = m_Book->CreateEmptyNavFile(true);
-            Resource * res = dynamic_cast<Resource *>(nav_resource);
+            Resource * res = qobject_cast<Resource *>(nav_resource);
             m_Book->GetOPF()->SetItemRefLinear(res, false);
         }
         m_Book->GetOPF()->SetNavResource(nav_resource);
     }
 
-    if (m_NCXNotInManifest) {
+    
+    if (m_NCXNotInManifest && m_PackageVersion.startsWith('2')) {
         // We manually created an NCX file because there wasn't one in the manifest.
         // Need to create a new manifest id for it.
         m_NCXId = m_Book->GetOPF()->AddNCXItem(m_NCXFilePath);
     }
 
-    // Ensure that our spine has a <spine toc="ncx"> element on it now in case it was missing.
-    m_Book->GetOPF()->UpdateNCXOnSpine(m_NCXId);
-    // Make sure the <item> for the NCX in the manifest reflects correct href path
-    m_Book->GetOPF()->UpdateNCXLocationInManifest(m_Book->GetNCX());
+    NCXResource * ncxresource = m_Book->GetNCX();
+ 
+    if (ncxresource) {
+        // Ensure that our spine has a <spine toc="ncx"> element on it now in case it was missing.
+        m_Book->GetOPF()->UpdateNCXOnSpine(m_NCXId);
+        // Make sure the <item> for the NCX in the manifest reflects correct href path
+        m_Book->GetOPF()->UpdateNCXLocationInManifest(ncxresource);
+    }
 
     // If spine was not present or did not contain any items, recreate the OPF from scratch
     // preserving any important metadata elements and making a new reading order.
@@ -424,6 +441,43 @@ void ImportEPUB::ExtractContainer()
 
             // If there is no file name then we can't do anything with it.
             if (!qfile_name.isEmpty()) {
+
+	        // for security reasons against maliciously crafted zip archives
+                // we need the file path to always be inside the target folder 
+                // and not outside, so we will remove all illegal backslashes
+                // and all relative upward paths segments "/../" from the zip's local 
+                // file name/path before prepending the target folder to create 
+                // the final path
+
+	        QString original_path = qfile_name;
+	        bool evil_or_corrupt_epub = false;
+
+                if (qfile_name.contains("\\")) evil_or_corrupt_epub = true; 
+	        qfile_name = "/" + qfile_name.replace("\\","");
+
+                if (qfile_name.contains("/../")) evil_or_corrupt_epub = true;
+	        qfile_name = qfile_name.replace("/../","/");
+
+                while(qfile_name.startsWith("/")) { 
+		    qfile_name = qfile_name.remove(0,1);
+		}
+
+                if (cp437_file_name.contains("\\")) evil_or_corrupt_epub = true; 
+                cp437_file_name = "/" + cp437_file_name.replace("\\","");
+
+                if (cp437_file_name.contains("/../")) evil_or_corrupt_epub = true;
+	        cp437_file_name = cp437_file_name.replace("/../","/");
+
+                while(cp437_file_name.startsWith("/")) { 
+		    cp437_file_name = cp437_file_name.remove(0,1);
+		}
+
+                if (evil_or_corrupt_epub) {
+                    unzCloseCurrentFile(zfile);
+                    unzClose(zfile);
+                    throw (EPUBLoadParseError(QString(QObject::tr("Possible evil or corrupt epub file name: %1")).arg(original_path).toStdString()));
+                }
+
                 // We use the dir object to create the path in the temporary directory.
                 // Unfortunately, we need a dir ojbect to do this as it's not a static function.
                 QDir dir(m_ExtractedFolderPath);
@@ -527,19 +581,21 @@ void ImportEPUB::LocateOPF()
         container.addData(Utility::ReadUnicodeTextFile(fullpath));
     }
 
+    int num_opf = 0;
+
     while (!container.atEnd()) {
         container.readNext();
 
-        if (container.isStartElement() &&
-            container.name() == "rootfile"
-           ) {
+        if (container.isStartElement() && container.name() == "rootfile") {
             if (container.attributes().hasAttribute("media-type") &&
-                container.attributes().value("", "media-type") == OEBPS_MIMETYPE
-               ) {
-                m_OPFFilePath = m_ExtractedFolderPath + "/" + container.attributes().value("", "full-path").toString();
+                container.attributes().value("", "media-type") == OEBPS_MIMETYPE) {
                 // As per OCF spec, the first rootfile element
                 // with the OEBPS mimetype is considered the "main" one.
-                break;
+	        if (m_OPFFilePath.isEmpty()) {
+                    m_OPFFilePath = m_ExtractedFolderPath + "/" + container.attributes().value("", "full-path").toString();
+		}
+		num_opf++;
+
             }
         }
     }
@@ -553,6 +609,10 @@ void ImportEPUB::LocateOPF()
         throw (EPUBLoadParseError(error.toStdString()));
     }
 
+    if (num_opf > 1) {
+        Utility::DisplayStdWarningDialog(tr("This epub has multiple renditions (multiple OPF files). Editing this epub in Sigil will produce a normal single rendition epub using only the main (first) OPF file found."),"");
+    }
+
     if (m_OPFFilePath.isEmpty() || !QFile::exists(m_OPFFilePath)) {
         throw (EPUBLoadParseError(QString(QObject::tr("No appropriate OPF file found")).toStdString()));
     }
@@ -684,6 +744,8 @@ void ImportEPUB::ReadManifestItemElement(QXmlStreamReader *opf_reader)
 
     // find the epub root relative file path from the opf location and the item href
     QString file_path = m_opfDir.absolutePath() + "/" + href;
+    qDebug() << "creating manifest file path from: " << file_path;
+    file_path = Utility::resolveRelativeSegmentsInFilePath(file_path,"/");
     file_path = file_path.remove(0, m_ExtractedFolderPath.length() + 1); 
     
     if (type != NCX_MIMETYPE && extension != NCX_EXTENSION) {
@@ -726,9 +788,14 @@ void ImportEPUB::ReadManifestItemElement(QXmlStreamReader *opf_reader)
 void ImportEPUB::LocateOrCreateNCX(const QString &ncx_id_on_spine)
 {
     QString load_warning;
-    QString ncx_href = "not_found";
+    QString ncx_href = "";
     m_NCXId = ncx_id_on_spine;
 
+    // if epub2 must have an ncx
+    if (m_PackageVersion.startsWith('2')) {
+        m_Book->GetFolderKeeper()->AddNCXToFolder(m_PackageVersion);
+    }
+
     // Handle various failure conditions, such as:
     // - ncx not specified in the spine (search for a matching manifest item by extension)
     // - ncx specified in spine, but no matching manifest item entry (create a new one)
@@ -754,30 +821,43 @@ void ImportEPUB::LocateOrCreateNCX(const QString &ncx_id_on_spine)
             }
         }
     }
+    if (!ncx_href.isEmpty()) {
+        m_NCXFilePath = QFileInfo(m_OPFFilePath).absolutePath() % "/" % ncx_href;
 
-    m_NCXFilePath = QFileInfo(m_OPFFilePath).absolutePath() % "/" % ncx_href;
+	if (QFile::exists(m_NCXFilePath) && m_PackageVersion.startsWith('3')) {
+	    // only ask folderkeeper to create an NCX if an ncx already exists in this epub3
+            m_Book->GetFolderKeeper()->AddNCXToFolder(m_PackageVersion);
+	}
+    }
 
-    if (ncx_href.isEmpty() || !QFile::exists(m_NCXFilePath)) {
+    if (ncx_href.isEmpty() || m_NCXFilePath.isEmpty() || !QFile::exists(m_NCXFilePath)) {
         m_NCXNotInManifest = m_NCXId.isEmpty() || ncx_href.isEmpty();
         m_NCXId.clear();
-        // Things are really bad and no .ncx file was found in the manifest or
+
+        // For epub3 having an ncx is optional so do nothing here
+
+        // For epub2, having an ncx is required so things are really
+        // bad and no .ncx file was found in the manifest or
         // the file does not physically exist.  We need to create a new one.
-        m_NCXFilePath = QFileInfo(m_OPFFilePath).absolutePath() % "/" % NCX_FILE_NAME;
-        // Create a new file for the NCX.
-        NCXResource ncx_resource(m_ExtractedFolderPath, m_NCXFilePath, m_Book->GetFolderKeeper());
 
-        // We are relying on an identifier being set from the metadata.
-        // It might not have one if the book does not have the urn:uuid: format.
-        if (!m_UuidIdentifierValue.isEmpty()) {
-            ncx_resource.SetMainID(m_UuidIdentifierValue);
-        }
+        if ( m_PackageVersion.startsWith('2') ) {
+            m_NCXFilePath = QFileInfo(m_OPFFilePath).absolutePath() % "/" % NCX_FILE_NAME;
 
-        ncx_resource.SaveToDisk();
+            // Create a new file for the NCX.
+            NCXResource ncx_resource(m_ExtractedFolderPath, m_NCXFilePath, NULL);
+            ncx_resource.SetEpubVersion(m_PackageVersion);
 
-        if (m_PackageVersion.startsWith('3')) { 
-            load_warning = QObject::tr("Sigil has created a template NCX") + "\n" + 
-              QObject::tr("to support epub2 backwards compatibility.");
-        } else {
+            // We are relying on an identifier being set from the metadata.
+            // It might not have one if the book does not have the urn:uuid: format.
+            if (!m_UuidIdentifierValue.isEmpty()) {
+                ncx_resource.SetMainID(m_UuidIdentifierValue);
+            }
+
+            ncx_resource.SaveToDisk();
+	}
+
+	
+        if (m_PackageVersion.startsWith('2')) { 
             if (ncx_href.isEmpty()) {
                 load_warning = QObject::tr("The OPF file does not contain an NCX file.") + "\n" + 
                                " - " +  QObject::tr("Sigil has created a new one for you.");
@@ -802,12 +882,14 @@ void ImportEPUB::LoadInfrastructureFiles()
     QString OPFBookRelPath = m_OPFFilePath;
     OPFBookRelPath = OPFBookRelPath.remove(0,m_ExtractedFolderPath.length()+1);
     m_Book->GetOPF()->SetCurrentBookRelPath(OPFBookRelPath);
-
-    m_Book->GetNCX()->SetText(CleanSource::ProcessXML(Utility::ReadUnicodeTextFile(m_NCXFilePath),"application/x-dtbncx+xml"));
-    m_Book->GetNCX()->SetEpubVersion(m_PackageVersion);
-    QString NCXBookRelPath = m_NCXFilePath;
-    NCXBookRelPath = NCXBookRelPath.remove(0,m_ExtractedFolderPath.length()+1);
-    m_Book->GetNCX()->SetCurrentBookRelPath(NCXBookRelPath);
+    NCXResource * ncxresource = m_Book->GetNCX();
+    if (ncxresource) {
+        ncxresource->SetEpubVersion(m_PackageVersion);
+        ncxresource->SetText(CleanSource::ProcessXML(Utility::ReadUnicodeTextFile(m_NCXFilePath),"application/x-dtbncx+xml"));
+        QString NCXBookRelPath = m_NCXFilePath;
+        NCXBookRelPath = NCXBookRelPath.remove(0,m_ExtractedFolderPath.length()+1);
+        ncxresource->SetCurrentBookRelPath(NCXBookRelPath);
+    }
 }
 
 
