@@ -1063,6 +1063,8 @@ void BookBrowser::RemoveResources(QList<Resource *> tab_resources, QList<Resourc
         return;
     }
 
+    QString version = m_Book->GetConstOPF()->GetEpubVersion();
+
     Resource *next_resource = NULL;
 
     Resource * nav_resource =  m_Book->GetConstOPF()->GetNavResource();
@@ -1072,14 +1074,23 @@ void BookBrowser::RemoveResources(QList<Resource *> tab_resources, QList<Resourc
         );
         return;
     }
-    Resource::ResourceType resource_type = resources.first()->Type();
-    if (resource_type == Resource::OPFResourceType ||
-        resource_type == Resource::NCXResourceType) {
+    // do the same for ncx under epub2
+    NCXResource * ncx_resource = m_Book->GetNCX();
+    if (ncx_resource && resources.contains(ncx_resource)) {
         Utility::DisplayStdErrorDialog(
-            tr("Neither the NCX nor the OPF can be removed.")
+            tr("The NCX can not be removed.")
         );
         return;
-    } else if (resource_type == Resource::HTMLResourceType &&
+    }
+    Resource::ResourceType resource_type = resources.first()->Type();
+    if (resource_type == Resource::OPFResourceType) {
+        Utility::DisplayStdErrorDialog(
+            tr("The OPF is required for epub and can not be removed.")
+        );
+        return;
+    }
+
+    if (resource_type == Resource::HTMLResourceType &&
                resources.count() == m_Book->GetFolderKeeper()->GetResourceTypeList<HTMLResource>().count()) {
         {
             Utility::DisplayStdErrorDialog(
@@ -1250,27 +1261,40 @@ void BookBrowser::AddSemanticCode()
     }
     HTMLResource *html_resource = qobject_cast<HTMLResource *>(resource);
 
-    QStringList codes;
     QString version = m_Book->GetConstOPF()->GetEpubVersion();
+    HTMLResource * nav_resource = NULL;
     if (version.startsWith('3')) {
-        AddSemantics addmeaning(Landmarks::instance()->GetCodeMap(), this);
+        nav_resource = m_Book->GetConstOPF()->GetNavResource();
+    }
+
+    QStringList codes;
+    QString current_code;
+
+    if (version.startsWith('3')) {
+        NavProcessor navproc(nav_resource);
+        current_code = navproc.GetLandmarkCodeForResource(resource);
+    } else { 
+        current_code = m_Book->GetOPF()->GetGuideSemanticCodeForResource(resource);
+    }
+
+    if (version.startsWith('3')) {
+        AddSemantics addmeaning(Landmarks::instance()->GetCodeMap(), current_code, this);
         if (addmeaning.exec() == QDialog::Accepted) {
             codes = addmeaning.GetSelectedEntries();
             if (!codes.isEmpty()) {
                 QString new_code = codes.at(0);
-                NavProcessor navproc(m_Book->GetConstOPF()->GetNavResource());
-                navproc.AddLandmarkCode(html_resource, new_code);
-                // if new_code is valid for guide as well, update the guide too
-                QString guide_code = Landmarks::instance()->GuideLandMapping(new_code);
-                if (!guide_code.isEmpty()) {
-                    m_Book->GetOPF()->AddGuideSemanticCode(html_resource, guide_code);
+		// do not allow a user to change any semantics on the nav resource as it
+		// must be set to "toc"
+		if (html_resource != nav_resource) {
+                    NavProcessor navproc(nav_resource);
+                    navproc.AddLandmarkCode(html_resource, new_code);
                     m_OPFModel->Refresh();
-                }
-                emit BookContentModified();
+                    emit BookContentModified();
+		}
             }
         }
     } else {
-        AddSemantics addmeaning(GuideItems::instance()->GetCodeMap(), this);
+        AddSemantics addmeaning(GuideItems::instance()->GetCodeMap(), current_code, this);
         if (addmeaning.exec() == QDialog::Accepted) {
             codes = addmeaning.GetSelectedEntries();
             if (!codes.isEmpty()) {
@@ -1493,7 +1517,6 @@ bool BookBrowser::SuccessfullySetupContextMenu(const QPoint &point)
                                  (AllHTMLResources().count() > 1 && resources.count() != item_count));
             m_ContextMenu->addAction(m_Rename);
         }
-
         if (resource->Type() == Resource::HTMLResourceType) {
             m_ContextMenu->addAction(m_Merge);
             m_Merge->setEnabled(item_count > 1 ||
