@@ -47,6 +47,7 @@
 #include "MiscEditors/IndexEditorModel.h"
 #include "MiscEditors/SearchEditorModel.h"
 #include "Tabs/ContentTab.h"
+#include "ViewEditors/ElementIndex.h"
 
 const int MAX_RECENT_FILES = 5;
 const int STATUSBAR_MSG_DISPLAY_TIME = 7000;
@@ -149,33 +150,15 @@ public:
      */
     void SelectResources(QList<Resource *> resources);
 
-    /**
-     * Describes the type of the View mode
-     * currently used in FlowTab.
-     */
-    enum ViewState {
-        ViewState_Unknown = 0,     /**< Default non view that we don't know or care what it is */
-        ViewState_BookView = 10,   /**< The WYSIWYG view. */
-        ViewState_CodeView = 30    /**< The XHTML code editing view. */
-    };
-
     /**
      * The location of the last bookmark.
      */
     struct LocationBookmark {
         QString filename;
-        MainWindow::ViewState view_state;
         QString bv_caret_location_update;
         int cv_cursor_position;
     };
 
-    /**
-     * Returns the current view state.
-     *
-     * @return The current view state.
-     */
-    MainWindow::ViewState GetViewState();
-
     void CloseAllTabs();
 
     void SaveTabData();
@@ -212,10 +195,11 @@ public:
 
 
 public slots:
-    void AnyCodeView();
 
     void OpenUrl(const QUrl &url);
 
+    void ScrollCVToFragment(const QString &fragment);
+
     /**
      * Opens the specified resource in the specified view state.
      */
@@ -223,7 +207,6 @@ public slots:
                       int line_to_scroll_to = -1,
                       int position_to_scroll_to = -1,
                       const QString &caret_location_to_scroll_to = QString(),
-                      MainWindow::ViewState view_state = MainWindow::ViewState_Unknown,
                       const QUrl &fragment = QUrl(),
                       bool precede_current_tab = false);
 
@@ -231,13 +214,14 @@ public slots:
                                         int line_to_scroll_to = -1,
                                         int position_to_scroll_to = -1,
                                         const QString &caret_location_to_scroll_to = QString(),
-                                        MainWindow::ViewState view_state = MainWindow::ViewState_Unknown,
                                         const QUrl &fragment = QUrl(),
                                         bool precede_current_tab = false);
 
     void UpdateManifestProperties();
 
-    void GenerateNCXFromNav();
+    void GenerateNCXGuideFromNav();
+
+    void RemoveNCXGuideFromEpub3();
 
     void CreateIndex();
 
@@ -245,12 +229,16 @@ public slots:
 
     void ResourcesAddedOrDeleted();
 
+    void launchExternalXEditor();
 
 signals:
     void SettingsChanged();
 
 protected:
     void showEvent(QShowEvent *event);
+
+    void changeEvent(QEvent * event);
+
     /**
      * Workaround for Qt 4.8 bug, which does not save/restore window state
      * correctly if maximized at the time of calling saveGeometry().
@@ -363,7 +351,7 @@ private slots:
     void QuickLaunchPlugin(int i);
 
     /**
-     * Some controls (CodeView, BookView and combo boxes in F&R) inherit PasteTarget
+     * Some controls (CodeView and combo boxes in F&R) inherit PasteTarget
      * to allow various modeless/popup dialogs like Clipboard History, Clip Editor and
      * Insert Special Characters to insert text into the focused "PasteTarget" control.
      * These two slots will delegate the relevant signal to the current target if any.
@@ -393,11 +381,6 @@ private slots:
     void PasteClip19IntoCurrentTarget();
     void PasteClip20IntoCurrentTarget();
 
-    /**
-     * Implements the set BookView functionality.
-     */
-    void BookView();
-
     /**
      * Implements the set CodeView functionality.
      */
@@ -469,7 +452,7 @@ private slots:
      * Updates the toolbars/menus based on current state
      * and updates the tab state if requested
      */
-    void UpdateViewState(bool set_tab_state = true);
+    void UpdateMWState(bool set_tab_state = true);
 
     /**
      * Updates the toolbars based on current tab state and changes.
@@ -486,11 +469,6 @@ private slots:
      */
     void UpdateUIWhenTabsSwitch();
 
-    /**
-     * Set initial state for actions in Book View
-     */
-    void SetStateActionsBookView();
-
     /**
      * Set initial state for actions in Code View
      */
@@ -514,8 +492,8 @@ private slots:
 
     void UpdatePreviewRequest();
     void UpdatePreviewCSSRequest();
-    void UpdatePreview();
     void ScrollPreview();
+    void UpdatePreview();
     void InspectHTML();
 
     /**
@@ -564,7 +542,7 @@ private slots:
      * @param originating_resource  The original resource from which the content
      *                              was extracted to create the "old" tab/resource.
      * @see FlowTab::SplitSection, FlowTab::OldTabRequest,
-     *      BookViewEditor::SplitSection, Book::CreateSectionBreakOriginalResource
+     *      Book::CreateSectionBreakOriginalResource
      */
     void CreateSectionBreakOldTab(QString content, HTMLResource *originating_resource);
 
@@ -623,8 +601,6 @@ private slots:
     void MarkSelection();
     void ClearMarkedText(ContentTab *old_tab = NULL);
 
-    void ToggleViewState();
-
     void ApplyHeadingStyleToTab(const QString &heading_type);
     void SetPreserveHeadingAttributes(bool new_state);
 
@@ -678,8 +654,6 @@ private:
      */
     void WriteSettings();
 
-    void SetDefaultViewState();
-
     /**
      * Gets called on possible saves and asks the user
      * does he want to save.
@@ -832,13 +806,6 @@ private:
      */
     void BreakTabConnections(ContentTab *tab);
 
-    /**
-     * Sets the view state of the current tab to view_state
-     *
-     * @param view_state - The view state to set.
-     */
-    void SetViewState(MainWindow::ViewState view_state);
-
     void SetupPreviewTimer();
 
     ///////////////////////////////
@@ -954,11 +921,6 @@ private:
      */
     const QMap<QString, QString> c_LoadFilters;
 
-    /**
-     * Holds the view state for new/switched tabs
-     */
-    MainWindow::ViewState m_ViewState;
-
     /**
      * Collects signals and sends specific parameters to the connected slots.
      */
@@ -1010,7 +972,7 @@ private:
 
     HTMLResource *m_PreviousHTMLResource;
     QString m_PreviousHTMLText;
-    QList<ViewEditor::ElementIndex> m_PreviousHTMLLocation;
+    QList<ElementIndex> m_PreviousHTMLLocation;
 
     /**
      * dynamically updated plugin menus and actions
@@ -1025,6 +987,7 @@ private:
     QStringList m_pluginList;
     bool m_SaveCSS;
 
+    QList<QAction*> m_qlactions;
     /**
      * Holds all the widgets Qt Designer created for us.
      */
