@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2018, 2019  Kevin B. Hendricks, Stratford, Ontario, Canada
+**  Copyright (C) 2018-2019  Kevin B. Hendricks, Stratford, Ontario Canada
 **  Copyright (C) 2009, 2010, 2011  Strahinja Markovic  <strahinja.markovic@gmail.com>
 **
 **  This file is part of Sigil.
@@ -32,7 +32,9 @@
 #include <QtWidgets/QApplication>
 #include <QtWidgets/QMessageBox>
 #include <QXmlStreamReader>
+#include <QFile>
 #include <QFileInfo>
+#include <QTextStream>
 #include <QDebug>
 
 #include "Misc/PluginDB.h"
@@ -47,20 +49,19 @@
 #include "sigil_constants.h"
 #include "sigil_exception.h"
 
+
 #ifdef Q_OS_WIN32
-# include <QFile>
-# include <QTextStream>
-# include <QProcessEnvironment>
-# include <QtWidgets/QPlainTextEdit>
-# include "ViewEditors/BookViewPreview.h"
+#include <QtWidgets/QPlainTextEdit>
 static const QString WIN_CLIPBOARD_ERROR = "QClipboard::setMimeData: Failed to set data on clipboard";
 static const int RETRY_DELAY_MS = 5;
 #endif
 
 #ifdef Q_OS_MAC
-# include <QFileDialog>
-# include <QKeySequence>
-# include <QAction>
+#include <QFileDialog>
+#include <QKeySequence>
+#include <QAction>
+extern void disableWindowTabbing();
+extern void removeMacosSpecificMenuItems();
 #endif
 
 // Creates a MainWindow instance depending
@@ -128,24 +129,27 @@ static QIcon GetApplicationIcon()
 void MessageHandler(QtMsgType type, const QMessageLogContext &context, const QString &message)
 {
     QString error_message;
-    QString win_debug_message;
+    QString qt_debug_message;
 
     switch (type) {
         // TODO: should go to a log
         case QtDebugMsg:
-            win_debug_message = QString("Debug: %1").arg(message.toLatin1().constData());
+            qt_debug_message = QString("Debug: %1").arg(message.toLatin1().constData());
             fprintf(stderr, "Debug: %s\n", message.toLatin1().constData());
             break;
 #if QT_VERSION >= 0x050600
         case QtInfoMsg:
+            qt_debug_message = QString("Info: %1").arg(message.toLatin1().constData());
             fprintf(stderr, "Info: %s\n", message.toLatin1().constData());
             break;
 #endif
         // TODO: should go to a log
         case QtWarningMsg:
+            qt_debug_message = QString("Warning: %1").arg(message.toLatin1().constData());
             fprintf(stderr, "Warning: %s\n", message.toLatin1().constData());
             break;
         case QtCriticalMsg:
+            qt_debug_message = QString("Critical: %1").arg(message.toLatin1().constData());
             error_message = QString(message.toLatin1().constData());
 #ifdef Q_OS_WIN32
             // On Windows there is a known issue with the clipboard that results in some copy
@@ -163,15 +167,6 @@ void MessageHandler(QtMsgType type, const QMessageLogContext &context, const QSt
                         break;
                     }
 
-                    // BV/PV copying is a little different, in that the focus widget is set to
-                    // the parent editor (unlike CodeView's QPlainTextEdit).
-                    BookViewPreview *bookViewPreview = dynamic_cast<BookViewPreview *>(widget);
-
-                    if (bookViewPreview) {
-                        QTimer::singleShot(RETRY_DELAY_MS, bookViewPreview, SLOT(copy()));
-                        break;
-                    }
-
                     // Same issue can happen on a QLineEdit / QComboBox
                     QLineEdit *lineEdit = dynamic_cast<QLineEdit *>(widget);
 
@@ -197,18 +192,17 @@ void MessageHandler(QtMsgType type, const QMessageLogContext &context, const QSt
             Utility::DisplayExceptionErrorDialog(QString("Fatal: %1").arg(QString(message)));
             abort();
     }
-#ifdef Q_OS_WIN32
-    // qDebug() prints to WINDOWS_SIGIL_DEBUG_LOGFILE environment variable on Windows.
+    
+    // qDebug() prints to SIGIL_DEBUG_LOGFILE environment variable.
     // User must have permissions to write to the location or no file will be created.
-    if (qEnvironmentVariableIsSet("WINDOWS_SIGIL_DEBUG_LOGFILE") && !qEnvironmentVariableIsEmpty("WINDOWS_SIGIL_DEBUG_LOGFILE")) {
-        QString sigil_log_file;
-        sigil_log_file = QProcessEnvironment::systemEnvironment().value("WINDOWS_SIGIL_DEBUG_LOGFILE", "").trimmed();
-        QFile outFile(sigil_log_file);
-        outFile.open(QIODevice::WriteOnly | QIODevice::Append | QIODevice::Text);
-        QTextStream ts(&outFile);
-        ts << win_debug_message << endl;
-    }
-#endif
+    QString sigil_log_file;
+    sigil_log_file = Utility::GetEnvironmentVar("SIGIL_DEBUG_LOGFILE");
+	if (!sigil_log_file.isEmpty()) {
+            QFile outFile(sigil_log_file);
+            outFile.open(QIODevice::WriteOnly | QIODevice::Append | QIODevice::Text);
+            QTextStream ts(&outFile);
+            ts << qt_debug_message << endl;
+	}
 }
 
 
@@ -222,7 +216,12 @@ void VerifyPlugins()
 // Application entry point
 int main(int argc, char *argv[])
 {
-    QT_REQUIRE_VERSION(argc, argv, "5.0.0");
+#if !defined(Q_OS_WIN32) && !defined(Q_OS_MAC)
+    QT_REQUIRE_VERSION(argc, argv, "5.9.0");
+#else
+    QT_REQUIRE_VERSION(argc, argv, "5.12.3");
+#endif
+
 #ifndef QT_DEBUG
     qInstallMessageHandler(MessageHandler);
 #endif
@@ -238,7 +237,6 @@ int main(int argc, char *argv[])
 #if QT_VERSION >= 0x050900
     QCoreApplication::setAttribute(Qt::AA_DisableShaderDiskCache);
 #endif
-
  
 #if 0   // On recent processors with multiple cores this leads to over 40 threads at times
         // We prevent Qt from constantly creating and deleting threads.
@@ -249,6 +247,18 @@ int main(int argc, char *argv[])
 
     MainApplication app(argc, argv);
 
+#ifdef Q_OS_MAC
+    disableWindowTabbing();
+    removeMacosSpecificMenuItems();
+#endif
+
+    // Install an event filter for the application
+    // so we can catch OS X's file open events
+    // This needs to be done upfront to prevent events from
+    // being missed
+    AppEventFilter *filter = new AppEventFilter(&app);
+    app.installEventFilter(filter);
+
     // drag and drop in main tab bar is too touchy and that can cause problems.
     // default drag distance limit is much too small especially for hpi displays
     // startDragDistance default is just 10 pixels
@@ -330,24 +340,21 @@ int main(int argc, char *argv[])
         UpdateChecker *checker = new UpdateChecker(&app);
         checker->CheckForUpdate();
 
-        // Install an event filter for the application
-        // so we can catch OS X's file open events
-        AppEventFilter *filter = new AppEventFilter(&app);
-        app.installEventFilter(filter);
-
         QStringList arguments = QCoreApplication::arguments();
 
 #ifdef Q_OS_MAC
-        // now process main app events so that any startup 
+	// now process main app events so that any startup 
         // FileOpen event will be processed for macOS
-        QCoreApplication::processEvents();
+	QCoreApplication::processEvents();
 
-        QString filepath = filter->getInitialFilePath();
+	QString filepath = filter->getInitialFilePath();
 
-        // if one found append it to argv for processing as normal
-        if ((arguments.size() == 1) && !filepath.isEmpty()) {
-            arguments << QFileInfo(filepath).absoluteFilePath();
-        }
+	// if one found append it to argv for processing as normal
+	if ((arguments.size() == 1) && !filepath.isEmpty()) {
+	    arguments << QFileInfo(filepath).absoluteFilePath();
+	}
+
+	if (filepath.isEmpty()) filter->setInitialFilePath(QString("placeholder"));
 #endif
 
         if (arguments.contains("-t")) {
@@ -409,7 +416,7 @@ int main(int argc, char *argv[])
             widget->show();
             return app.exec();
         }
-    } catch (std::exception e) {
+    } catch (std::exception &e) {
         Utility::DisplayExceptionErrorDialog(e.what());
         return 1;
     }
